@@ -35,9 +35,41 @@ from thop import clever_format, profile
 
 
 
+def generate_classes(VOCdevkit_path):
+        
+    xmlfilepath = os.path.join(
+        VOCdevkit_path, 'VOC2007', 'Annotations')
+    
+    temp_xml = os.listdir(xmlfilepath)
+    class_names = set()
+
+    print("Generate labels.txt...")
+
+    for xml in temp_xml:
+        if xml.endswith(".xml"):        
+            tree = ET.parse(os.path.join(xmlfilepath, xml))
+            root = tree.getroot()
+
+            for element in root.findall('object'):
+                class_name = element[0].text
+                class_names.add(class_name)
+
+    flabels = open('labels.txt', 'w')
+    
+    for label in class_names:
+        
+        label = label + '\n'
+
+        flabels.write(label)
+
+    flabels.close()
+
+    print("Generate labels.txt done.")
+
+
 class Yolov5:
 
-    def __init__(self, classes_path: str = 'voc_classes.txt',
+    def __init__(self,
                  VOCdevkit_path: str = '.', anchors: List[list] =
                  [[10., 13.], [16., 30.], [33., 23.], [30., 61.],
                   [62., 45.], [59., 119.], [116., 90.], [156., 198.],
@@ -45,7 +77,9 @@ class Yolov5:
                  input_shape: list = [640, 640], anchors_mask: List[list] =
                  [[6, 7, 8], [3, 4, 5], [0, 1, 2]]) -> None:
 
-        self.classes_path = classes_path
+        generate_classes(VOCdevkit_path) # generate labels.txt
+        
+        self.classes_path = 'labels.txt'
         self.VOCdevkit_path = VOCdevkit_path
         self.anchors = anchors
         self.classes, self.num_classes = get_classes(self.classes_path)
@@ -109,10 +143,15 @@ class Yolov5:
 
         if annotation_mode == 0 or annotation_mode == 1:
             print("Generate txt in ImageSets.")
+
             xmlfilepath = os.path.join(
                 self.VOCdevkit_path, 'VOC2007', 'Annotations')
             saveBasePath = os.path.join(
                 self.VOCdevkit_path, 'VOC2007', 'ImageSets/Main')
+
+            if not os.path.exists(print(saveBasePath):
+                os.makedirs(saveBasePath)
+            
             temp_xml = os.listdir(xmlfilepath)
             total_xml = []
             for xml in temp_xml:
@@ -480,12 +519,12 @@ class Yolov5:
                                       to proceed with the training.')
                 wanted_epoch = wanted_step // (num_train //
                                                Unfreeze_batch_size) + 1
-                print("\n\033[1;33;44m[Warning] 使用%s优化器时，建议将训练总步长设置到%d以上。\033[0m" % (
-                    optimizer_type, wanted_step))
-                print("\033[1;33;44m[Warning] 本次运行的总训练数据量为%d，Unfreeze_batch_size为%d，共训练%d个Epoch，计算出总训练步长为%d。\033[0m" % (
-                    num_train, Unfreeze_batch_size, UnFreeze_Epoch, total_step))
-                print("\033[1;33;44m[Warning] 由于总训练步长为%d，小于建议总步长%d，建议设置总世代为%d。\033[0m" % (
-                    total_step, wanted_step, wanted_epoch))
+                # print("\n\033[1;33;44m[Warning] 使用%s优化器时，建议将训练总步长设置到%d以上。\033[0m" % (
+                #     optimizer_type, wanted_step))
+                # print("\033[1;33;44m[Warning] 本次运行的总训练数据量为%d，Unfreeze_batch_size为%d，共训练%d个Epoch，计算出总训练步长为%d。\033[0m" % (
+                #     num_train, Unfreeze_batch_size, UnFreeze_Epoch, total_step))
+                # print("\033[1;33;44m[Warning] 由于总训练步长为%d，小于建议总步长%d，建议设置总世代为%d。\033[0m" % (
+                #     total_step, wanted_step, wanted_epoch))
 
         #------------------------------------------------------#
         #   主干特征提取网络特征通用，冻结训练可以加快训练速度
