@@ -456,12 +456,12 @@ class Yolox:
                                       to proceed with the training.')
                 wanted_epoch = wanted_step // (num_train //
                                                Unfreeze_batch_size) + 1
-                print("\n\033[1;33;44m[Warning] 使用%s优化器时，建议将训练总步长设置到%d以上。\033[0m" % (
-                    optimizer_type, wanted_step))
-                print("\033[1;33;44m[Warning] 本次运行的总训练数据量为%d，Unfreeze_batch_size为%d，共训练%d个Epoch，计算出总训练步长为%d。\033[0m" % (
-                    num_train, Unfreeze_batch_size, UnFreeze_Epoch, total_step))
-                print("\033[1;33;44m[Warning] 由于总训练步长为%d，小于建议总步长%d，建议设置总世代为%d。\033[0m" % (
-                    total_step, wanted_step, wanted_epoch))
+                # print("\n\033[1;33;44m[Warning] 使用%s优化器时，建议将训练总步长设置到%d以上。\033[0m" % (
+                #     optimizer_type, wanted_step))
+                # print("\033[1;33;44m[Warning] 本次运行的总训练数据量为%d，Unfreeze_batch_size为%d，共训练%d个Epoch，计算出总训练步长为%d。\033[0m" % (
+                #     num_train, Unfreeze_batch_size, UnFreeze_Epoch, total_step))
+                # print("\033[1;33;44m[Warning] 由于总训练步长为%d，小于建议总步长%d，建议设置总世代为%d。\033[0m" % (
+                #     total_step, wanted_step, wanted_epoch))
 
         #------------------------------------------------------#
         #   主干特征提取网络特征通用，冻结训练可以加快训练速度
